# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/99_misc.ipynb.

# %% auto 0
__all__ = ['isin', 'arein']

# %% ../nbs/99_misc.ipynb 4
from typing import Any, Type, Union, Callable, Literal, Iterable, TypeAlias, TypeGuard, ParamSpec

from .core import isiter

# %% ../nbs/99_misc.ipynb 6
def isin(x, refs: Iterable) -> bool: return x in refs
def arein(x: Iterable, refs: Iterable) -> bool:
    return isiter(x) and isiter(refs) and all(isin(y, refs) for y in x)
